@@ -1,30 +1,14 @@
 use strict;
 use warnings;
-
 package Perl::Critic::Policy::Lax::ProhibitLeadingZeros::ExceptChmod;
+{
+  $Perl::Critic::Policy::Lax::ProhibitLeadingZeros::ExceptChmod::VERSION = '0.009';
+}
+# ABSTRACT: leading zeroes are okay as the first arg to chmod
 
-=head1 NAME
-
-Perl::Critic::Policy::Lax::ProhibitLeadingZeros::ExceptChmod
-
-=head1 DESCRIPTION
-
-This is a stupid mistake:
-
-  my $x = 1231;
-  my $y = 2345;
-  my $z = 0032;
-
-This is not:
-
-  chmod 0600, "secret_file.txt";
-
-=cut
 
 use Perl::Critic::Utils;
-use base qw(Perl::Critic::Policy);
-
-our $VERSION = '0.008';
+use parent qw(Perl::Critic::Policy);
 
 my $DESCRIPTION = q{Integer with leading zeros outside of chmod};
 my $EXPLANATION = "Only use leading zeros on numbers indicating file modes";
@@ -50,24 +34,45 @@ sub violates {
 
     return if $working and ($working->children)[0] eq 'chmod';
   }
-    
+
   return $self->violation($DESCRIPTION, $EXPLANATION, $element);
 }
 
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Perl::Critic::Policy::Lax::ProhibitLeadingZeros::ExceptChmod - leading zeroes are okay as the first arg to chmod
+
+=head1 VERSION
+
+version 0.009
+
+=head1 DESCRIPTION
+
+This is a stupid mistake:
+
+  my $x = 1231;
+  my $y = 2345;
+  my $z = 0032;
+
+This is not:
+
+  chmod 0600, "secret_file.txt";
+
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo Signes <rjbs@cpan.org>
 
-Adapted from ValuesAndExpressions::ProhibitLeadingZeros by Jeffrey Ryan
-Thalhammer.
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT
+This software is copyright (c) 2012 by Ricardo Signes <rjbs@cpan.org>.
 
-Copyright (c) 2007 Ricardo Signes and Jeffrey Ryan Thalhammer.
-
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
